@@ -3,16 +3,18 @@ import json
 from datetime import datetime
 from unittest import mock
 
-import pytz
 from django.test import TransactionTestCase
 from django.urls import reverse
+from freezegun import freeze_time
 
 from django_forest.tests.fixtures.schema import test_schema
 from django_forest.utils.schema import Schema
 from django_forest.utils.schema.json_api_schema import JsonApiSchema
 from django_forest.utils.scope import ScopeManager
+from django_forest.utils.date import get_timezone
 
-
+@mock.patch('django_forest.utils.scope.ScopeManager._has_cache_expired', return_value=False)
+@mock.patch('jose.jwt.decode', return_value={'id': 1, 'rendering_id': 1})    
 class StatsStatsWithParametersViewTests(TransactionTestCase):
     fixtures = ['question.json', 'choice.json', ]
 
@@ -26,7 +28,7 @@ class StatsStatsWithParametersViewTests(TransactionTestCase):
         ScopeManager.cache = {
             '1': {
                 'scopes': {},
-                'fetched_at': datetime(2021, 7, 8, 9, 20, 22, 582772, tzinfo=pytz.UTC)
+                'fetched_at': 'useless_here'
             }
         }
 
@@ -35,10 +37,7 @@ class StatsStatsWithParametersViewTests(TransactionTestCase):
         JsonApiSchema._registry = {}
         ScopeManager.cache = {}
 
-    @mock.patch('jose.jwt.decode', return_value={'id': 1, 'rendering_id': 1})
-    @mock.patch('django_forest.utils.scope.datetime')
-    def test_get_value_count(self, mocked_scope_datetime, mocked_decode):
-        mocked_scope_datetime.now.return_value = datetime(2021, 7, 8, 9, 20, 23, 582772, tzinfo=pytz.UTC)
+    def test_get_value_count(self, *args, **kwargs):
         body = {
             'aggregate': 'Count',
             'collection': 'tests_question',
@@ -57,10 +56,7 @@ class StatsStatsWithParametersViewTests(TransactionTestCase):
         })
         self.assertEqual(data['data']['type'], 'stats')
 
-    @mock.patch('jose.jwt.decode', return_value={'id': 1, 'rendering_id': 1})
-    @mock.patch('django_forest.utils.scope.datetime')
-    def test_get_value_sum(self, mocked_scope_datetime, mocked_decode):
-        mocked_scope_datetime.now.return_value = datetime(2021, 7, 8, 9, 20, 23, 582772, tzinfo=pytz.UTC)
+    def test_get_value_sum(self, *args, **kwargs):
         body = {
             'aggregate': 'Sum',
             'aggregate_field': 'id',
@@ -80,10 +76,7 @@ class StatsStatsWithParametersViewTests(TransactionTestCase):
         })
         self.assertEqual(data['data']['type'], 'stats')
 
-    @mock.patch('jose.jwt.decode', return_value={'id': 1, 'rendering_id': 1})
-    @mock.patch('django_forest.utils.scope.datetime')
-    def test_get_value_sum_empty(self, mocked_scope_datetime, mocked_decode):
-        mocked_scope_datetime.now.return_value = datetime(2021, 7, 8, 9, 20, 23, 582772, tzinfo=pytz.UTC)
+    def test_get_value_sum_empty(self, *args, **kwargs):
         body = {
             'aggregate': 'Sum',
             'aggregate_field': 'id',
@@ -103,12 +96,10 @@ class StatsStatsWithParametersViewTests(TransactionTestCase):
         })
         self.assertEqual(data['data']['type'], 'stats')
 
-    @mock.patch('jose.jwt.decode', return_value={'id': 1, 'rendering_id': 1})
-    @mock.patch('django_forest.resources.utils.queryset.filters.date.datetime')
-    @mock.patch('django_forest.utils.scope.datetime')
-    def test_get_value_count_previous_yesterday(self, mocked_scope_datetime, mocked_datetime, mocked_decode):
-        mocked_scope_datetime.now.return_value = datetime(2021, 7, 8, 9, 20, 23, 582772, tzinfo=pytz.UTC)
-        mocked_datetime.now.return_value = datetime(2021, 6, 4, 9, 20, 22, 582772, tzinfo=pytz.UTC)
+    @freeze_time(
+        lambda: datetime(2021, 6, 4, 9, 20, 22, 582772, tzinfo=get_timezone('UTC'))
+    )
+    def test_get_value_count_previous_yesterday(self, *args, **kwargs):
         body = {
             'aggregate': 'Count',
             'collection': 'tests_question',
@@ -129,12 +120,10 @@ class StatsStatsWithParametersViewTests(TransactionTestCase):
         })
         self.assertEqual(data['data']['type'], 'stats')
 
-    @mock.patch('jose.jwt.decode', return_value={'id': 1, 'rendering_id': 1})
-    @mock.patch('django_forest.resources.utils.queryset.filters.date.datetime')
-    @mock.patch('django_forest.utils.scope.datetime')
-    def test_get_value_count_previous_yesterday_aggregator(self, mocked_scope_datetime, mocked_datetime, mocked_decode):
-        mocked_scope_datetime.now.return_value = datetime(2021, 7, 8, 9, 20, 23, 582772, tzinfo=pytz.UTC)
-        mocked_datetime.now.return_value = datetime(2021, 6, 4, 9, 20, 22, 582772, tzinfo=pytz.UTC)
+    @freeze_time(
+        lambda: datetime(2021, 6, 4, 9, 20, 22, 582772, tzinfo=get_timezone('UTC'))
+    )
+    def test_get_value_count_previous_yesterday_aggregator(self, *args, **kwargs):
         body = {
             'aggregate': 'Count',
             'collection': 'tests_question',
@@ -155,12 +144,10 @@ class StatsStatsWithParametersViewTests(TransactionTestCase):
         })
         self.assertEqual(data['data']['type'], 'stats')
 
-    @mock.patch('jose.jwt.decode', return_value={'id': 1, 'rendering_id': 1})
-    @mock.patch('django_forest.resources.utils.queryset.filters.date.datetime')
-    @mock.patch('django_forest.utils.scope.datetime')
-    def test_get_value_count_previous_month(self, mocked_scope_datetime, mocked_datetime, mocked_decode):
-        mocked_scope_datetime.now.return_value = datetime(2021, 7, 8, 9, 20, 23, 582772, tzinfo=pytz.UTC)
-        mocked_datetime.now.return_value = datetime(2021, 7, 4, 9, 20, 22, 582772, tzinfo=pytz.UTC)
+    @freeze_time(
+        lambda: datetime(2021, 7, 4, 9, 20, 22, 582772, tzinfo=get_timezone('UTC'))
+    )
+    def test_get_value_count_previous_month(self, *args, **kwargs):
         body = {
             'aggregate': 'Count',
             'collection': 'tests_question',
@@ -181,12 +168,10 @@ class StatsStatsWithParametersViewTests(TransactionTestCase):
         })
         self.assertEqual(data['data']['type'], 'stats')
 
-    @mock.patch('jose.jwt.decode', return_value={'id': 1, 'rendering_id': 1})
-    @mock.patch('django_forest.resources.utils.queryset.filters.date.datetime')
-    @mock.patch('django_forest.utils.scope.datetime')
-    def test_get_value_count_previous_quarter(self, mocked_scope_datetime, mocked_datetime, mocked_decode):
-        mocked_scope_datetime.now.return_value = datetime(2021, 7, 8, 9, 20, 23, 582772, tzinfo=pytz.UTC)
-        mocked_datetime.now.return_value = datetime(2021, 7, 4, 9, 20, 22, 582772, tzinfo=pytz.UTC)
+    @freeze_time(
+        lambda: datetime(2021, 7, 4, 9, 20, 22, 582772, tzinfo=get_timezone('UTC'))
+    )
+    def test_get_value_count_previous_quarter(self, *args, **kwargs):
         body = {
             'aggregate': 'Count',
             'collection': 'tests_question',
@@ -207,12 +192,10 @@ class StatsStatsWithParametersViewTests(TransactionTestCase):
         })
         self.assertEqual(data['data']['type'], 'stats')
 
-    @mock.patch('jose.jwt.decode', return_value={'id': 1, 'rendering_id': 1})
-    @mock.patch('django_forest.resources.utils.queryset.filters.date.datetime')
-    @mock.patch('django_forest.utils.scope.datetime')
-    def test_get_value_count_previous_quarter_to_date(self, mocked_scope_datetime, mocked_datetime, mocked_decode):
-        mocked_scope_datetime.now.return_value = datetime(2021, 7, 8, 9, 20, 23, 582772, tzinfo=pytz.UTC)
-        mocked_datetime.now.return_value = datetime(2021, 7, 4, 9, 20, 22, 582772, tzinfo=pytz.UTC)
+    @freeze_time(
+        lambda: datetime(2021, 7, 4, 9, 20, 22, 582772, tzinfo=get_timezone('UTC'))
+    )
+    def test_get_value_count_previous_quarter_to_date(self, *args, **kwargs):
         body = {
             'aggregate': 'Count',
             'collection': 'tests_question',
@@ -233,12 +216,10 @@ class StatsStatsWithParametersViewTests(TransactionTestCase):
         })
         self.assertEqual(data['data']['type'], 'stats')
 
-    @mock.patch('jose.jwt.decode', return_value={'id': 1, 'rendering_id': 1})
-    @mock.patch('django_forest.resources.utils.queryset.filters.date.datetime')
-    @mock.patch('django_forest.utils.scope.datetime')
-    def test_get_value_count_previous_year(self, mocked_scope_datetime, mocked_datetime, mocked_decode):
-        mocked_scope_datetime.now.return_value = datetime(2021, 7, 8, 9, 20, 23, 582772, tzinfo=pytz.UTC)
-        mocked_datetime.now.return_value = datetime(2022, 7, 4, 9, 20, 22, 582772, tzinfo=pytz.UTC)
+    @freeze_time(
+        lambda: datetime(2022, 7, 4, 9, 20, 22, 582772, tzinfo=get_timezone('UTC'))
+    )
+    def test_get_value_count_previous_year(self, *args, **kwargs):
         body = {
             'aggregate': 'Count',
             'collection': 'tests_question',
@@ -259,10 +240,7 @@ class StatsStatsWithParametersViewTests(TransactionTestCase):
         })
         self.assertEqual(data['data']['type'], 'stats')
 
-    @mock.patch('jose.jwt.decode', return_value={'id': 1, 'rendering_id': 1})
-    @mock.patch('django_forest.utils.scope.datetime')
-    def test_get_objective_count(self, mocked_scope_datetime, mocked_decode):
-        mocked_scope_datetime.now.return_value = datetime(2021, 7, 8, 9, 20, 23, 582772, tzinfo=pytz.UTC)
+    def test_get_objective_count(self, *args, **kwargs):
         body = {
             'aggregate': 'Count',
             'collection': 'tests_question',
@@ -281,10 +259,7 @@ class StatsStatsWithParametersViewTests(TransactionTestCase):
         })
         self.assertEqual(data['data']['type'], 'stats')
 
-    @mock.patch('jose.jwt.decode', return_value={'id': 1, 'rendering_id': 1})
-    @mock.patch('django_forest.utils.scope.datetime')
-    def test_get_pie_count(self, mocked_scope_datetime, mocked_decode):
-        mocked_scope_datetime.now.return_value = datetime(2021, 7, 8, 9, 20, 23, 582772, tzinfo=pytz.UTC)
+    def test_get_pie_count(self, *args, **kwargs):
         body = {
             'aggregate': 'Count',
             'collection': 'tests_question',
@@ -310,10 +285,7 @@ class StatsStatsWithParametersViewTests(TransactionTestCase):
         })
         self.assertEqual(data['data']['type'], 'stats')
 
-    @mock.patch('jose.jwt.decode', return_value={'id': 1, 'rendering_id': 1})
-    @mock.patch('django_forest.utils.scope.datetime')
-    def test_get_pie_sum(self, mocked_scope_datetime, mocked_decode):
-        mocked_scope_datetime.now.return_value = datetime(2021, 7, 8, 9, 20, 23, 582772, tzinfo=pytz.UTC)
+    def test_get_pie_sum(self, *args, **kwargs):
         body = {
             'aggregate': 'Sum',
             'aggregate_field': 'id',
@@ -340,10 +312,7 @@ class StatsStatsWithParametersViewTests(TransactionTestCase):
         })
         self.assertEqual(data['data']['type'], 'stats')
 
-    @mock.patch('jose.jwt.decode', return_value={'id': 1, 'rendering_id': 1})
-    @mock.patch('django_forest.utils.scope.datetime')
-    def test_get_line_count_day(self, mocked_scope_datetime, mocked_decode):
-        mocked_scope_datetime.now.return_value = datetime(2021, 7, 8, 9, 20, 23, 582772, tzinfo=pytz.UTC)
+    def test_get_line_count_day(self, *args, **kwargs):
         body = {
             'aggregate': 'Count',
             'collection': 'tests_question',
@@ -373,10 +342,7 @@ class StatsStatsWithParametersViewTests(TransactionTestCase):
         })
         self.assertEqual(data['data']['type'], 'stats')
 
-    @mock.patch('jose.jwt.decode', return_value={'id': 1, 'rendering_id': 1})
-    @mock.patch('django_forest.utils.scope.datetime')
-    def test_get_line_count_week(self, mocked_scope_datetime, mocked_decode):
-        mocked_scope_datetime.now.return_value = datetime(2021, 7, 8, 9, 20, 23, 582772, tzinfo=pytz.UTC)
+    def test_get_line_count_week(self, *args, **kwargs):
         body = {
             'aggregate': 'Count',
             'collection': 'tests_question',
@@ -400,10 +366,7 @@ class StatsStatsWithParametersViewTests(TransactionTestCase):
         })
         self.assertEqual(data['data']['type'], 'stats')
 
-    @mock.patch('jose.jwt.decode', return_value={'id': 1, 'rendering_id': 1})
-    @mock.patch('django_forest.utils.scope.datetime')
-    def test_get_line_count_month(self, mocked_scope_datetime, mocked_decode):
-        mocked_scope_datetime.now.return_value = datetime(2021, 7, 8, 9, 20, 23, 582772, tzinfo=pytz.UTC)
+    def test_get_line_count_month(self, *args, **kwargs):
         body = {
             'aggregate': 'Count',
             'collection': 'tests_question',
@@ -427,10 +390,7 @@ class StatsStatsWithParametersViewTests(TransactionTestCase):
         })
         self.assertEqual(data['data']['type'], 'stats')
 
-    @mock.patch('jose.jwt.decode', return_value={'id': 1, 'rendering_id': 1})
-    @mock.patch('django_forest.utils.scope.datetime')
-    def test_get_line_count_year(self, mocked_scope_datetime, mocked_decode):
-        mocked_scope_datetime.now.return_value = datetime(2021, 7, 8, 9, 20, 23, 582772, tzinfo=pytz.UTC)
+    def test_get_line_count_year(self, *args, **kwargs):
         body = {
             'aggregate': 'Count',
             'collection': 'tests_question',
@@ -454,10 +414,7 @@ class StatsStatsWithParametersViewTests(TransactionTestCase):
         })
         self.assertEqual(data['data']['type'], 'stats')
 
-    @mock.patch('jose.jwt.decode', return_value={'id': 1, 'rendering_id': 1})
-    @mock.patch('django_forest.utils.scope.datetime')
-    def test_get_line_count_empty(self, mocked_scope_datetime, mocked_decode):
-        mocked_scope_datetime.now.return_value = datetime(2021, 7, 8, 9, 20, 23, 582772, tzinfo=pytz.UTC)
+    def test_get_line_count_empty(self, *args, **kwargs):
         body = {
             'aggregate': 'Count',
             'collection': 'tests_question',
@@ -475,10 +432,7 @@ class StatsStatsWithParametersViewTests(TransactionTestCase):
         })
         self.assertEqual(data['data']['type'], 'stats')
 
-    @mock.patch('jose.jwt.decode', return_value={'id': 1, 'rendering_id': 1})
-    @mock.patch('django_forest.utils.scope.datetime')
-    def test_get_leaderboard_count(self, mocked_scope_datetime, mocked_decode):
-        mocked_scope_datetime.now.return_value = datetime(2021, 7, 8, 9, 20, 23, 582772, tzinfo=pytz.UTC)
+    def test_get_leaderboard_count(self, *args, **kwargs):
         body = {
             'aggregate': 'Count',
             'collection': 'tests_question',
